# Authors

| Name | Email | GitHub handle | Title | Role |
|------|-------|---------------|-------|------|
| John P. Didion | jdidion AT dnanexus DOT com | [@jdidion](//github.com/jdidion) | Principal Scientist, DNAnexus | Developer |
| Michael T. Neylon | dude AT place DOT com | [@michaeltneylon](//github.com/michaeltneylon) | Associate Consultant, Eli Lilly | Developer |